aboutsummaryrefslogtreecommitdiff
path: root/opcodes
diff options
context:
space:
mode:
authorJeff Law <law@redhat.com>1996-10-03 16:42:22 +0000
committerJeff Law <law@redhat.com>1996-10-03 16:42:22 +0000
commitae1b99e42dbce238cd7eb5efd38672b8306f1148 (patch)
tree62cc3acea6d14f13f329d7ea5e4813255f126d27 /opcodes
parentfeede9b69925572e68d3859b2fcb610bddd2e713 (diff)
downloadgdb-ae1b99e42dbce238cd7eb5efd38672b8306f1148.zip
gdb-ae1b99e42dbce238cd7eb5efd38672b8306f1148.tar.gz
gdb-ae1b99e42dbce238cd7eb5efd38672b8306f1148.tar.bz2
Grrr. The mn10200 and mn10300 are _not_ similar enough to easily support
with a single generic configuration. So break them up into two different configurations. See the individual ChangeLogs for additional detail.
Diffstat (limited to 'opcodes')
-rw-r--r--opcodes/.Sanitize4
-rw-r--r--opcodes/ChangeLog10
-rw-r--r--[-rwxr-xr-x]opcodes/mn10200-dis.c (renamed from opcodes/mn10x00-dis.c)6
-rw-r--r--opcodes/mn10200-opc.c (renamed from opcodes/mn10x00-opc.c)12
-rw-r--r--opcodes/mn10300-dis.c34
-rw-r--r--opcodes/mn10300-opc.c51
6 files changed, 108 insertions, 9 deletions
diff --git a/opcodes/.Sanitize b/opcodes/.Sanitize
index 4c61e37..4aa3000 100644
--- a/opcodes/.Sanitize
+++ b/opcodes/.Sanitize
@@ -74,6 +74,10 @@ m88k-dis.c
makefile.vms
mips-dis.c
mips-opc.c
+mn10200-dis.c
+mn10200-opc.c
+mn10300-dis.c
+mn10300-opc.c
mpw-config.in
mpw-make.sed
ns32k-dis.c
diff --git a/opcodes/ChangeLog b/opcodes/ChangeLog
index de99849..b9ee3181 100644
--- a/opcodes/ChangeLog
+++ b/opcodes/ChangeLog
@@ -1,3 +1,13 @@
+Thu Oct 3 10:06:07 1996 Jeffrey A Law (law@cygnus.com)
+
+ * mn10200-opc.c, mn10300-opc.c: New files.
+ * mn10200-dis.c, mn10300-dis.c: New files.
+ * mn10x00-opc.c, mn10x00-dis.c: Deleted.
+ * disassemble.c: Break mn10x00 support into 10200 and 10300
+ support.
+ * configure.in: Likewise.
+ * configure: Rebuilt.
+
Thu Oct 3 15:59:12 1996 Jason Molenda (crash@godzilla.cygnus.co.jp)
* Makefile.in (MOSTLYCLEAN): Move config.log to distclean.
diff --git a/opcodes/mn10x00-dis.c b/opcodes/mn10200-dis.c
index cd068e3..5aa0cb8 100755..100644
--- a/opcodes/mn10x00-dis.c
+++ b/opcodes/mn10200-dis.c
@@ -1,4 +1,4 @@
-/* Disassemble MN10x00 instructions.
+/* Disassemble MN10200 instructions.
Copyright (C) 1996 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify
@@ -19,7 +19,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
#include <stdio.h>
#include "ansidecl.h"
-#include "opcode/mn10x00.h"
+#include "opcode/mn10200.h"
#include "dis-asm.h"
static void disassemble PARAMS ((bfd_vma memaddr,
@@ -27,7 +27,7 @@ static void disassemble PARAMS ((bfd_vma memaddr,
unsigned long insn));
int
-print_insn_mn10x00 (memaddr, info)
+print_insn_mn10200 (memaddr, info)
bfd_vma memaddr;
struct disassemble_info *info;
{
diff --git a/opcodes/mn10300-dis.c b/opcodes/mn10300-dis.c
new file mode 100644
index 0000000..b81d493
--- /dev/null
+++ b/opcodes/mn10300-dis.c
@@ -0,0 +1,34 @@
+/* Disassemble MN10300 instructions.
+ Copyright (C) 1996 Free Software Foundation, Inc.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+
+
+#include <stdio.h>
+
+#include "ansidecl.h"
+#include "opcode/mn10300.h"
+#include "dis-asm.h"
+
+static void disassemble PARAMS ((bfd_vma memaddr,
+ struct disassemble_info *info,
+ unsigned long insn));
+
+int
+print_insn_mn10300 (memaddr, info)
+ bfd_vma memaddr;
+ struct disassemble_info *info;
+{
+}
diff --git a/opcodes/mn10300-opc.c b/opcodes/mn10300-opc.c
new file mode 100644
index 0000000..800a45b
--- /dev/null
+++ b/opcodes/mn10300-opc.c
@@ -0,0 +1,51 @@
+/* Assemble Matsushita MN10300 instructions.
+ Copyright (C) 1996 Free Software Foundation, Inc.
+
+This program is free software; you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2 of the License, or
+(at your option) any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program; if not, write to the Free Software
+Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+
+#include "ansidecl.h"
+#include "opcode/mn10300.h"
+
+
+const struct mn10300_operand mn10300_operands[] = {
+#define UNUSED 0
+ { 0, 0, 0 },
+} ;
+
+
+/* The opcode table.
+
+ The format of the opcode table is:
+
+ NAME OPCODE MASK { OPERANDS }
+
+ NAME is the name of the instruction.
+ OPCODE is the instruction opcode.
+ MASK is the opcode mask; this is used to tell the disassembler
+ which bits in the actual opcode must match OPCODE.
+ OPERANDS is the list of operands.
+
+ The disassembler reads the table in order and prints the first
+ instruction which matches, so this table is sorted to put more
+ specific instructions before more general instructions. It is also
+ sorted by major opcode. */
+
+const struct mn10300_opcode mn10300_opcodes[] = {
+{ 0, 0, 0, {0}, } } ;
+
+const int mn10300_num_opcodes =
+ sizeof (mn10300_opcodes) / sizeof (mn10300_opcodes[0]);
+
+
diff --git a/opcodes/mn10x00-opc.c b/opcodes/mn10200-opc.c
index 278756b..7b4abfa 100644
--- a/opcodes/mn10x00-opc.c
+++ b/opcodes/mn10200-opc.c
@@ -1,4 +1,4 @@
/* Assemble Matsushita MN10x00 instructions.
Copyright (C) 1996 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify
@@ -16,10 +16,10 @@ along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
#include "ansidecl.h"
-#include "opcode/mn10x00.h"
+#include "opcode/mn10200.h"
-const struct mn10x00_operand mn10x00_operands[] = {
+const struct mn10200_operand mn10200_operands[] = {
#define UNUSED 0
{ 0, 0, 0 },
} ;
@@ -42,10 +42,10 @@ const struct mn10x00_operand mn10x00_operands[] = {
specific instructions before more general instructions. It is also
sorted by major opcode. */
-const struct mn10x00_opcode mn10x00_opcodes[] = {
+const struct mn10200_opcode mn10200_opcodes[] = {
{ 0, 0, 0, {0}, } } ;
-const int mn10x00_num_opcodes =
- sizeof (mn10x00_opcodes) / sizeof (mn10x00_opcodes[0]);
+const int mn10200_num_opcodes =
+ sizeof (mn10200_opcodes) / sizeof (mn10200_opcodes[0]);
@@ -1,4 +1,4 @@
-/* Assemble Matsushita MN10x00 instructions.
+/* Assemble Matsushita MN10200 instructions.
Copyright (C) 1996 Free Software Foundation, Inc.
This program is free software; you can redistribute it and/or modify